@@ -39,7 +39,7 @@ rbcc <- function(X, UC, C, n, type= c("xbar", "R", "S"), confidence_level=0.9973
       y <- matrix(Y,ncol=n)
       qy <- qcc::qcc(y, type = "xbar.one", confidence.level = confidence_level, plot = FALSE) # calculation of risk based xbar
       ybar <- qy$statistics     #  observed xbar with measurement errors
-      T3 <- mean(qx$statistics)-K*(qx$std.dev)/sqrt(n)     # set lower control limit based on observed xbar
+      T3 <- mean(qx$statistics)-K*(qx$std.dev)/sqrt(n)      # set lower control limit based on observed xbar
       T4 <- mean(qx$statistics)+K*(qx$std.dev)/sqrt(n)     # set upper control limit based on observed xbar
     }
     if(n>=2)
@@ -50,25 +50,25 @@ rbcc <- function(X, UC, C, n, type= c("xbar", "R", "S"), confidence_level=0.9973
       x <- matrix(X,ncol=n) #  Data with subgroups
       qx <- qcc::qcc(x, type = "xbar", confidence.level = confidence_level, plot = FALSE)
       xbar <- qx$statistics          # real values of Xbar statistic
-      T1 <- qx$limits[1]             # LCL of Xbar chart
-      T2 <- qx$limits[2]             # UCL of xbar chart
+      T1 <- mean(qx$statistics)-3*(qx$std.dev)/sqrt(n)             # LCL of Xbar chart
+      T2 <- mean(qx$statistics)+3*(qx$std.dev)/sqrt(n) #qx$limits[2]             # UCL of xbar chart
       
       Y <- X+UC                      # measurement error data matrix
       y <- matrix(Y,ncol=n)
       qy <- qcc::qcc(y, type = "xbar", confidence.level = confidence_level, plot = FALSE) # calculation of risk based xbar
       ybar <- qy$statistics     #  observed xbar with measurement errors
-      T3 <- mean(qx$statistics)-K*(qx$std.dev)/sqrt(n)               # set lower control limit based on observed xbar
-      T4 <- mean(qx$statistics)+K*(qx$std.dev)/sqrt(n)   
+      T3 <- mean(qy$statistics)-K*(qy$std.dev)/sqrt(n)               # set lower control limit based on observed xbar
+      T4 <- mean(qy$statistics)+K*(qy$std.dev)/sqrt(n)   
     }
     # -----------------calculation of costs and define cases (boolean)-----------
     
     P1 <- ((T1 < xbar & xbar < T2) & (T3< ybar & ybar<T4))*1  # correct acceptance
-    P2 <- ((T1 < xbar & xbar < T2) & (T4< ybar | ybar<T3))*1 # type I error
-    P3 <- ((T2 < xbar|xbar < T1) & (T3< ybar& ybar<T4))*1 # type II error
-    P4 <- ((T2 < xbar|xbar < T1) & (T4< ybar| ybar<T3))*1 # correct rejecting
+    P2 <- ((T1 < xbar & xbar < T2) & (ybar<T3 | T4< ybar))*1 # type I error
+    P3 <- ((xbar < T1| T2 < xbar) & (T3< ybar & ybar<T4))*1 # type II error
+    P4 <- ((xbar < T1| T2 < xbar) & (ybar<T3 | T4< ybar))*1 # correct rejecting
     C0 <- sum(P1)*C[1]+sum(P2)*C[2]+sum(P3)*C[3]+sum(P4)*C[4] # calculation of total cost during the process
     C1 <- sum(P1)*C[1]    # total cost related to decision 1 (c11)
-    C2 <- sum(P2)*C[2]    # total cost related to decision 2 (c10)
+    C2 <- sum(P2)*C[2]   # total cost related to decision 2 (c10)
     C3 <- sum(P3)*C[3]    # total cost related to decision 3 (c01)
     C4 <- sum(P4)*C[4]    # total cost related to decision 4 (c00)
     output <- list(cost0=C0, cost1= C1, cost2= C2, cost3= C3, cost4= C4, LCLx=T1, UCLx=T2, LCLy=T3, UCLy=T4, real=xbar, Observed= ybar)
