@@ -27,12 +27,12 @@ rbewmacc_opt <- function (X, UC, C, n=1, lambada=0.20, nsigmas=3, K_init= 0, LKL
   {nsigmas <- 3 }
   if(missing(K_init))
   {K_init <- 0}
-
   fcn=function(K_init) rbewmacc(X, UC, C, n, lambada, nsigmas, K_init)[[1]]
-  Q=pracma::fminbnd(fcn, LKL, UKL)
+  Q<-stats::optimize(fcn, c(LKL, UKL))
+  #pracma::fminbnd(fcn, LKL, UKL)
   Kopt<-Q[[1]]
   H_opt<-rbewmacc(X, UC, C, n, lambada, nsigmas,K=Kopt)
   H_opt$par<- Kopt
- class(H_opt)<-"rbcc"
+  class(H_opt)<-"rbcc"
   return(H_opt)
 }
